@@ -23,7 +23,6 @@
 #include "ui.h"
 
 #include <glib/gi18n.h>
-#include <gconf/gconf-client.h>
 #include <gtk/gtk.h>
 #include <string.h>
 
@@ -31,7 +30,6 @@
 #include "ui-commands.h"
 #include "file.h"
 #include "prefs.h"
-#include "stock.h"
 #include "window.h"
 #include "recent.h" 
 
@@ -271,154 +269,154 @@ static GtkActionEntry entries[] = {
 
 	/* Objects action entries. */
 	{ "ObjectsArrowMode",
-	  GL_STOCK_ARROW,
+	  "glabels-arrow",
 	  N_("Select Mode"),
 	  NULL,
 	  N_("Select, move and modify objects"),
 	  G_CALLBACK (gl_ui_cmd_objects_arrow_mode) },
 
 	{ "ObjectsCreateText",
-	  GL_STOCK_TEXT,
+	  "glabels-text",
 	  N_("Text"),
 	  NULL,
 	  N_("Create text object"),
 	  G_CALLBACK (gl_ui_cmd_objects_create_text) },
 
 	{ "ObjectsCreateBox",
-	  GL_STOCK_BOX,
+	  "glabels-box",
 	  N_("Box"),
 	  NULL,
 	  N_("Create box/rectangle object"),
 	  G_CALLBACK (gl_ui_cmd_objects_create_box) },
 
 	{ "ObjectsCreateLine",
-	  GL_STOCK_LINE,
+	  "glabels-line",
 	  N_("Line"),
 	  NULL,
 	  N_("Create line object"),
 	  G_CALLBACK (gl_ui_cmd_objects_create_line) },
 
 	{ "ObjectsCreateEllipse",
-	  GL_STOCK_ELLIPSE,
+	  "glabels-ellipse",
 	  N_("Ellipse"),
 	  NULL,
 	  N_("Create ellipse/circle object"),
 	  G_CALLBACK (gl_ui_cmd_objects_create_ellipse) },
 
 	{ "ObjectsCreateImage",
-	  GL_STOCK_IMAGE,
+	  "glabels-image",
 	  N_("Image"),
 	  NULL,
 	  N_("Create image object"),
 	  G_CALLBACK (gl_ui_cmd_objects_create_image) },
 
 	{ "ObjectsCreateBarcode",
-	  GL_STOCK_BARCODE,
+	  "glabels-barcode",
 	  N_("Barcode"),
 	  NULL,
 	  N_("Create barcode object"),
 	  G_CALLBACK (gl_ui_cmd_objects_create_barcode) },
 	
 	{ "ObjectsRaise",
-	  GL_STOCK_ORDER_TOP,
+	  "glabels-order-top",
 	  N_("Bring to front"),
 	  NULL,
 	  N_("Raise object to top"),
 	  G_CALLBACK (gl_ui_cmd_objects_raise) },
 
 	{ "ObjectsLower",
-	  GL_STOCK_ORDER_BOTTOM,
+	  "glabels-order-bottom",
 	  N_("Send to back"),
 	  NULL,
 	  N_("Lower object to bottom"),
 	  G_CALLBACK (gl_ui_cmd_objects_lower) },
 
 	{ "ObjectsRotateLeft",
-	  GL_STOCK_ROTATE_LEFT,
+	  "glabels-rotate-left",
 	  N_("Rotate left"),
 	  NULL,
 	  N_("Rotate object 90 degrees counter-clockwise"),
 	  G_CALLBACK (gl_ui_cmd_objects_rotate_left) },
 
 	{ "ObjectsRotateRight",
-	  GL_STOCK_ROTATE_RIGHT,
+	  "glabels-rotate-right",
 	  N_("Rotate right"),
 	  NULL,
 	  N_("Rotate object 90 degrees clockwise"),
 	  G_CALLBACK (gl_ui_cmd_objects_rotate_right) },
 
 	{ "ObjectsFlipHorizontal",
-	  GL_STOCK_FLIP_HORIZ,
+	  "glabels-flip-horiz",
 	  N_("Flip horizontally"),
 	  NULL,
 	  N_("Flip object horizontally"),
 	  G_CALLBACK (gl_ui_cmd_objects_flip_horiz) },
 
 	{ "ObjectsFlipVertical",
-	  GL_STOCK_FLIP_VERT,
+	  "glabels-flip-vert",
 	  N_("Flip vertically"),
 	  NULL,
 	  N_("Flip object vertically"),
 	  G_CALLBACK (gl_ui_cmd_objects_flip_vert) },
 
 	{ "ObjectsAlignLeft",
-	  GL_STOCK_ALIGN_LEFT,
+	  "glabels-align-left",
 	  N_("Align left"),
 	  NULL,
 	  N_("Align objects to left edges"),
 	  G_CALLBACK (gl_ui_cmd_objects_align_left) },
 
 	{ "ObjectsAlignRight",
-	  GL_STOCK_ALIGN_RIGHT,
+	  "glabels-align-right",
 	  N_("Align right"),
 	  NULL,
 	  N_("Align objects to right edges"),
 	  G_CALLBACK (gl_ui_cmd_objects_align_right) },
 
 	{ "ObjectsAlignHCenter",
-	  GL_STOCK_ALIGN_HCENTER,
+	  "glabels-align-hcenter",
 	  N_("Align horizontal center"),
 	  NULL,
 	  N_("Align objects to horizontal centers"),
 	  G_CALLBACK (gl_ui_cmd_objects_align_hcenter) },
 
 	{ "ObjectsAlignTop",
-	  GL_STOCK_ALIGN_TOP,
+	  "glabels-align-top",
 	  N_("Align tops"),
 	  NULL,
 	  N_("Align objects to top edges"),
 	  G_CALLBACK (gl_ui_cmd_objects_align_top) },
 
 	{ "ObjectsAlignBottom",
-	  GL_STOCK_ALIGN_BOTTOM,
+	  "glabels-align-bottom",
 	  N_("Align bottoms"),
 	  NULL,
 	  N_("Align objects to bottom edges"),
 	  G_CALLBACK (gl_ui_cmd_objects_align_bottom) },
 
 	{ "ObjectsAlignVCenter",
-	  GL_STOCK_ALIGN_VCENTER,
+	  "glabels-align-vcenter",
 	  N_("Align vertical center"),
 	  NULL,
 	  N_("Align objects to vertical centers"),
 	  G_CALLBACK (gl_ui_cmd_objects_align_vcenter) },
 
 	{ "ObjectsCenterHorizontal",
-	  GL_STOCK_CENTER_HORIZ,
+	  "glabels-center-horiz",
 	  N_("Center horizontally"),
 	  NULL,
 	  N_("Center objects to horizontal label center"),
 	  G_CALLBACK (gl_ui_cmd_objects_center_horiz) },
 
 	{ "ObjectsCenterVertical",
-	  GL_STOCK_CENTER_VERT,
+	  "glabels-center-vert",
 	  N_("Center vertically"),
 	  NULL,
 	  N_("Center objects to vertical label center"),
 	  G_CALLBACK (gl_ui_cmd_objects_center_vert) },
 
 	{ "ObjectsMergeProperties",
-	  GL_STOCK_MERGE,
+	  "glabels-merge",
 	  N_("Merge properties"),
 	  NULL,
 	  N_("Edit merge properties"),
